@@ -172,9 +172,11 @@ def dsq_main():
         colored = True
         if not supports_color() :
             colored = False
-        if os.environ.get("force_ansicolor","") in ["true","yes","y","1"] :
+        if os.environ.get("force_ansicolor","").lower() in ["true","yes","y","1"] :
             colored = True
-        _x_args.plain = colored
+        elif os.environ.get("force_ansicolor","").lower() in ["false","no","n","0"] :
+            colored = False
+        _x_args.plain = not colored
     if _x_args.keys_included :
         _xdt_keys_included = dict()
         for w in  _x_args.keys_included.split(",") :
